@@ -52,7 +52,7 @@ class Repository:
             Log.trace('Saved entity {0} with id {1}', entity_type, model.id)
         except Exception as e:
             Log.error(f'An error ocurred: {e}')
-            Log.error(traceback.format_exc()))
+            Log.error(traceback.format_exc())
 
 
     def update(self, entity_from_database: any, entity: any) -> any:
