@@ -7,6 +7,10 @@ class Config:
         # read config.ini file
         self.config.read(path)
 
+    def set(self, section: str, key: str, value: str) -> None:
+        if section in self.config and key in self.config[section]:
+            self.config[section][key] = value
+
     def get(self, section: str, key: str, default: any=None):
         # get config value
         if section in self.config and key in self.config[section]:
